pub struct MaxTpsArgs {Show 26 fields
tps: u64,
duration: u64,
accounts: NonZeroU64,
mnemonic: MnemonicArg,
from_mnemonic_index: u32,
fee_token: Address,
target_urls: Vec<Url>,
max_concurrent_requests: usize,
max_concurrent_transactions: usize,
fd_limit: Option<u64>,
node_commit_sha: Option<String>,
build_profile: Option<String>,
benchmark_mode: Option<String>,
tip20_weight: f64,
place_order_weight: f64,
swap_weight: f64,
erc20_weight: f64,
mpp_weight: f64,
mpp_contract_address: Option<Address>,
existing_recipients: bool,
sample_size: usize,
faucet: bool,
faucet_url: Option<Url>,
clear_txpool: bool,
use_2d_nonces: bool,
use_standard_nonces: bool,
}Expand description
Run maximum TPS throughput benchmarking
Fields
tps: u64Target transactions per second
duration: u64Test duration in seconds
accounts: NonZeroU64Number of accounts for pre-generation
mnemonic: MnemonicArgMnemonic for generating accounts
from_mnemonic_index: u32fee_token: Addresstarget_urls: Vec<Url>Target URLs for network connections (comma-separated or multiple –target-urls)
max_concurrent_requests: usizeA limit of the maximum number of concurrent requests, prevents issues with too many connections open at once.
max_concurrent_transactions: usizeA number of transaction to send, before waiting for their receipts, that should be likely safe.
Large amount of transactions in a block will result in system transaction OutOfGas error.
fd_limit: Option<u64>File descriptor limit to set
node_commit_sha: Option<String>Node commit SHA for metadata
build_profile: Option<String>Build profile for metadata (e.g., “release”, “debug”, “maxperf”)
benchmark_mode: Option<String>Benchmark mode for metadata (e.g., “max_tps”, “stress_test”)
tip20_weight: f64A weight that determines the likelihood of generating a TIP-20 transfer transaction.
place_order_weight: f64A weight that determines the likelihood of generating a DEX place transaction.
swap_weight: f64A weight that determines the likelihood of generating a DEX swapExactAmountIn transaction.
erc20_weight: f64A weight that determines the likelihood of generating an ERC-20 transfer transaction.
mpp_weight: f64A weight that determines the likelihood of generating an MPP channel open+close
transaction. Requires --mpp-contract-address.
mpp_contract_address: Option<Address>Address of a deployed TempoStreamChannel contract. Required when --mpp-weight > 0.
existing_recipients: boolSend transfers to existing signer accounts instead of random new addresses.
When enabled, TIP-20 and ERC-20 transfers are sent to the bench’s own signer addresses (which already exist on-chain), avoiding cold SSTORE for account creation. This tests pure transfer throughput without state growth.
sample_size: usizeAn amount of receipts to wait for after sending all the transactions.
faucet: boolFund accounts from the faucet before running the benchmark.
Calls tempo_fundAddress for each account.
faucet_url: Option<Url>URL for the faucet service. If not provided, uses the first target URL.
clear_txpool: boolClear the transaction pool before running the benchmark.
Calls admin_clearTxpool.
use_2d_nonces: boolUse 2D nonces instead of expiring nonces.
By default, tempo-bench uses expiring nonces (TIP-1009) which use a circular buffer for replay protection, avoiding state bloat. Use this flag to switch to 2D nonces which store nonce state per (address, nonce_key) pair.
use_standard_nonces: boolUse standard sequential nonces instead of expiring nonces.
This disables both expiring nonces and 2D nonces, using traditional sequential nonce management.
Implementations
Sourceimpl MaxTpsArgs
impl MaxTpsArgs
const WEIGHT_PRECISION: f64 = 1000.0
pub async fn run(self) -> Result<()>
async fn run_with_manager<F: TxFiller<TempoNetwork> + 'static>( self, signer_provider_manager: SignerProviderManager<F>, ) -> Result<()>